pub struct JsonValidatorBuilder { /* private fields */ }Expand description
Builder for creating JSON validation instances
The builder receives configuration values directly and constructs constraints internally.
Implementations
Sourceimpl JsonValidatorBuilder
impl JsonValidatorBuilder
Sourcepub fn with_max_depth(self, depth: usize) -> Self
pub fn with_max_depth(self, depth: usize) -> Self
Sets the maximum depth of nested containers
Sourcepub fn with_max_array_length(self, length: usize) -> Self
pub fn with_max_array_length(self, length: usize) -> Self
Sets the maximum number of elements in arrays
Sourcepub fn with_max_string_length(self, length: usize) -> Self
pub fn with_max_string_length(self, length: usize) -> Self
Sets the maximum length of string values
Sourcepub fn with_max_object_entries(self, count: usize) -> Self
pub fn with_max_object_entries(self, count: usize) -> Self
Sets the maximum number of entries in objects
Sourcepub fn with_max_key_length(self, length: usize) -> Self
pub fn with_max_key_length(self, length: usize) -> Self
Sets the maximum length of key names in objects
Sourcepub fn build(self) -> JsonValidator
pub fn build(self) -> JsonValidator
Builds the validation instance with the specified configuration